.. _api:

SPGL1 API
=========

Main Solver
-----------
.. currentmodule:: spgl1

.. autosummary::
   :toctree: generated/

    spgl1


Other Solvers
-------------
.. currentmodule:: spgl1

.. autosummary::
   :toctree: generated/

    oneprojector
    spg_bp
    spg_bpdn
    spg_lasso
    spg_mmv
